@@ -2,7 +2,7 @@ package Net::AMQP::RabbitMQ;
 use strict;
 use warnings;
 
-our $VERSION = '1.500000';
+our $VERSION = '1.600000';
 
 use XSLoader;
 XSLoader::load "Net::AMQP::RabbitMQ", $VERSION;
@@ -131,9 +131,11 @@ C<$options> is an optional hash respecting the following keys:
        exchange_type => $type,  #default 'direct'
        passive => $boolean,     #default 0
        durable => $boolean,     #default 0
-       auto_delete => $boolean, #default 1
+       auto_delete => $boolean, #default 0
      }
 
+Note that the default for the C<auto_delete> option is different for C<exchange_declare> and for C<queue_declare>.
+
 C<$arguments> is an optional hash of additional arguments to the RabbitMQ server, such as:
 
      {
@@ -196,6 +198,8 @@ C<$options> is an optional hash respecting the following keys:
        auto_delete => $boolean, #default 1
      }
 
+Note that the default for the C<auto_delete> option is different for C<exchange_declare> and for C<queue_declare>.
+
 C<$arguments> is an optional hash which will be passed to the server
 when the queue is created.  This can be used for creating mirrored
 queues by using the x-ha-policy header.
@@ -278,7 +282,7 @@ C<$props> is an optional hash (the AMQP 'props') respecting the following keys:
        delivery_mode => $integer,
        priority => $integer,
        timestamp => $integer,
-       header => $headers # This should be a hashref of keys and values.
+       headers => $headers # This should be a hashref of keys and values.
      }
 
 =head2 consume($channel, $queuename, $options)
@@ -483,6 +487,60 @@ the connection has been closed by the remote host, or otherwise invalidated,
 the socket will also be closed and should be re-opened before any additional
 calls are made.
 
+=head1 RUNNING THE TEST SUITE
+
+The test suite runs live tests against a RabbitMQ server at
+C<rabbitmq.thisaintnews.com>.  If you are in an environment that won't
+let you connect to this host (or the test server is down), you can use
+these environment variables:
+
+=over 4
+
+=item MQHOST
+
+Hostname or IP address of the RabbitMQ server to connect to (defaults
+to C<rabbitmq.thisaintnews.com>).
+
+=item MQUSERNAME
+
+Username for authentication (defaults to "nartest").
+
+=item MQPASSWORD
+
+Password for authentication (defaults to "reallysecure").
+
+=item MQSSL
+
+Whether the tests should run with SSL enabled (defaults to false, but
+see also C<MQSKIPSSL>).
+
+=item MQSSLCACERT
+
+Path to the certificate file for SSL-enabled connections, defaults to
+F<t/ssl/cacert.pem>.
+
+=item MQSSLVERIFYHOST
+
+Whether SSL hostname verification should be enabled (defaults to
+true).
+
+=item MQSSLINIT
+
+Whether the openssl library should be initialized (defaults to true).
+
+=item MQPORT
+
+Port of the RabbitMQ server to connect to (defaults to 5672, or 5673
+if SSL is enabled).
+
+=item MQSKIPSSL
+
+Whether the SSL tests should be skipped entirely.  This option exists
+because the SSL tests used to ignore C<MQSSL>, and to maintain
+backwards compatibility, still do.
+
+=back
+
 =head1 AUTHORS
 
 Theo Schlossnagle E<lt>jesus@omniti.comE<gt>
